@@ -1,7 +1,7 @@
 #!/bin/sh
 echo 'name: logict
-version: 0.5.0
-id: logict-0.5.0-b83a8b70c14872a428671ea0cd2e9db1
+version: 0.5.0.1
+id: logict-0.5.0.1-f5871108fc142912fe5ecea3a877dda7
 
 license: BSD3
 copyright: Copyright (c) 2007-2010, Dan Doel,
@@ -10,6 +10,7 @@ maintainer: dan.doel@gmail.com
 stability: Experimental
 homepage: http://code.haskell.org/~dolio/logict
 package-url:
+synopsis: A backtracking logic-programming monad.
 description: A continuation-based, backtracking, logic programming monad.
              An adaptation of the two-continuation implementation found
              in the paper "Backtracking, Interleaving, and Terminating
@@ -21,20 +22,21 @@ pkgpath: devel/hs-logict
 exposed: True
 exposed-modules: Control.Monad.Logic Control.Monad.Logic.Class
 hidden-modules:
-import-dirs: /usr/local/lib/ghc/logict-0.5.0
-library-dirs: /usr/local/lib/ghc/logict-0.5.0
-hs-libraries: HSlogict-0.5.0
+trusted: False
+import-dirs: /usr/local/lib/ghc/logict-0.5.0.1
+library-dirs: /usr/local/lib/ghc/logict-0.5.0.1
+hs-libraries: HSlogict-0.5.0.1
 extra-libraries:
 extra-ghci-libraries:
 include-dirs:
 includes:
-depends: base-4.3.1.0-4365831fa9af03083be195ed161cbbc1
-         mtl-2.0.1.0-5b7a9cce5565d8cc8721ba4f95becf1b
+depends: base-4.6.0.1-03845c6da2a0b3b4d0d49cc26c0cd3c0
+         mtl-2.1.2-94c72af955e94b8d7b2f359dadd0cb62
 hugs-options:
 cc-options:
 ld-options:
 framework-dirs:
 frameworks:
-haddock-interfaces: /usr/local/share/doc/hs-logict-0.5.0/html/logict.haddock
-haddock-html: /usr/local/share/doc/hs-logict-0.5.0/html
-' | '/usr/local/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-conf' "$@"
+haddock-interfaces: /usr/local/share/doc/hs-logict-0.5.0.1/html/logict.haddock
+haddock-html: /usr/local/share/doc/hs-logict-0.5.0.1/html
+' | '/usr/local/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"
